==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/WebApplicationFirewallMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Match Variable.
 */
public enum class WebApplicationFirewallMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable> {
    RemoteAddr(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RemoteAddr),
    RequestMethod(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestMethod),
    QueryString(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.QueryString),
    PostArgs(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.PostArgs),
    RequestUri(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestUri),
    RequestHeaders(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestHeaders),
    RequestBody(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestBody),
    RequestCookies(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestCookies),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable):
            WebApplicationFirewallMatchVariable =
            WebApplicationFirewallMatchVariable.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/WebApplicationFirewallMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Match Variable.
 */
public enum class WebApplicationFirewallMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable> {
    RemoteAddr(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RemoteAddr),
    RequestMethod(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestMethod),
    QueryString(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.QueryString),
    PostArgs(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.PostArgs),
    RequestUri(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestUri),
    RequestHeaders(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestHeaders),
    RequestBody(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestBody),
    RequestCookies(com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable.RequestCookies),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.WebApplicationFirewallMatchVariable): WebApplicationFirewallMatchVariable =
            WebApplicationFirewallMatchVariable.values().first { it.javaValue == javaType }
    }
}
